@@ -24,12 +24,13 @@ rgl.enum <- function ( name, ..., multi = FALSE)
 }
 
 rgl.enum.nodetype <- function (type) 
-rgl.enum( type, shapes=1, lights=2, bboxdeco=3, viewpoint=4, material=5, background=6, multi = TRUE )
+rgl.enum( type, shapes=1, lights=2, bboxdeco=3, userviewpoint=4, material=5, background=6, subscene=7, modelviewpoint=8, 
+          multi = TRUE )
 
 rgl.enum.attribtype <- function (attrib)
 rgl.enum( attrib, vertices=1, normals=2, colors=3, texcoords=4, dim=5, 
           texts=6, cex=7, adj=8, radii=9, centers=10, ids=11, 
-          usermatrix=12, types=13, flags=14 )
+          usermatrix=12, types=13, flags=14, offsets=15)
 
 rgl.enum.pixfmt <- function (fmt)
 rgl.enum( fmt, png=0 )
