@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: glgui.cpp 1131 2014-09-06 20:28:54Z murdoch $
+// $Id: glgui.cpp 1137 2014-09-24 19:03:24Z murdoch $
 
 #include <cstdio>
 #ifdef HAVE_FREETYPE
@@ -48,7 +48,14 @@ GLboolean GLFont::justify(double width, double height, double adjx, double adjy,
     glGetDoublev(GL_CURRENT_RASTER_POSITION, pos);    
     pos[0] = pos[0] - scaling*width*(adjx-basex); 
     pos[1] = pos[1] - scaling*height*(adjy-basey);
-    gluUnProject( pos[0], pos[1], pos[2], rc.subscene->modelMatrix, rc.subscene->projMatrix, rc.subscene->pviewport, pos2, pos2 + 1, pos2 + 2);
+    GLint pviewport[4] = {rc.subscene->pviewport.x, 
+                          rc.subscene->pviewport.y, 
+                          rc.subscene->pviewport.width, 
+                          rc.subscene->pviewport.height};
+    GLdouble modelMatrix[16], projMatrix[16];
+    rc.subscene->modelMatrix.getData(modelMatrix);
+    rc.subscene->projMatrix.getData(projMatrix);
+    gluUnProject( pos[0], pos[1], pos[2], modelMatrix, projMatrix, pviewport, pos2, pos2 + 1, pos2 + 2);
     glRasterPos3dv(pos2);
   }
   
